@@ -483,6 +483,19 @@ class JsonSchemaParser(Parser):
             self.enum_field_as_literal == LiteralType.One and len(obj.enum) == 1
         )
 
+    def is_constraints_field(self, obj: JsonSchemaObject) -> bool:
+        return obj.is_array or (
+            self.field_constraints
+            and not (
+                obj.ref
+                or obj.anyOf
+                or obj.oneOf
+                or obj.allOf
+                or obj.is_object
+                or obj.enum
+            )
+        )
+
     def get_object_field(
         self,
         *,
@@ -493,27 +506,13 @@ class JsonSchemaParser(Parser):
         alias: Optional[str],
         original_field_name: Optional[str],
     ) -> DataModelFieldBase:
-        if field.is_array or (
-            self.field_constraints
-            and not (
-                field.ref
-                or field.anyOf
-                or field.oneOf
-                or field.allOf
-                or field.is_object
-                or field.enum
-            )
-        ):
-            constraints: Optional[Mapping[str, Any]] = field.dict()
-        else:
-            constraints = None
         return self.data_model_field_type(
             name=field_name,
             default=field.default,
             data_type=field_type,
             required=required,
             alias=alias,
-            constraints=constraints,
+            constraints=field.dict() if self.is_constraints_field(field) else None,
             nullable=field.nullable
             if self.strict_nullable and (field.has_default or required)
             else None,
@@ -523,6 +522,7 @@ class JsonSchemaParser(Parser):
             use_field_description=self.use_field_description,
             use_default_kwarg=self.use_default_kwarg,
             original_name=original_field_name,
+            has_default=field.has_default,
         )
 
     def get_data_type(self, obj: JsonSchemaObject) -> DataType:
@@ -925,10 +925,7 @@ class JsonSchemaParser(Parser):
             )
         elif item.enum:
             if self.should_parse_enum_as_literal(item):
-                enum_literals = item.enum
-                if item.nullable:
-                    enum_literals = [i for i in item.enum if i is not None]
-                return self.data_type(literals=enum_literals)
+                return self.parse_enum_as_literal(item)
             return self.parse_enum(
                 name, item, get_special_path('enum', path), singular_name=singular_name
             )
@@ -1016,6 +1013,7 @@ class JsonSchemaParser(Parser):
             use_annotated=self.use_annotated,
             use_field_description=self.use_field_description,
             original_name=None,
+            has_default=obj.has_default,
         )
 
     def parse_array(
@@ -1052,6 +1050,7 @@ class JsonSchemaParser(Parser):
                 use_annotated=self.use_annotated,
                 use_field_description=self.use_field_description,
                 original_name=None,
+                has_default=field.has_default,
             )
 
         data_model_root = self.data_model_root_type(
@@ -1096,6 +1095,11 @@ class JsonSchemaParser(Parser):
                 data_type = data_types[0]
         elif obj.patternProperties:
             data_type = self.parse_pattern_properties(name, obj.patternProperties, path)
+        elif obj.enum:
+            if self.should_parse_enum_as_literal(obj):
+                data_type = self.parse_enum_as_literal(obj)
+            else:  # pragma: no cover
+                data_type = self.parse_enum(name, obj, path)
         elif obj.type:
             data_type = self.get_data_type(obj)
         else:
@@ -1127,6 +1131,7 @@ class JsonSchemaParser(Parser):
                     use_annotated=self.use_annotated,
                     use_field_description=self.use_field_description,
                     original_name=None,
+                    has_default=obj.has_default,
                 )
             ],
             custom_base_class=self.base_class,
@@ -1138,6 +1143,9 @@ class JsonSchemaParser(Parser):
         self.results.append(data_model_root_type)
         return self.data_type(reference=reference)
 
+    def parse_enum_as_literal(self, obj: JsonSchemaObject) -> DataType:
+        return self.data_type(literals=[i for i in obj.enum if i is not None])
+
     def parse_enum(
         self,
         name: str,
@@ -1414,7 +1422,7 @@ class JsonSchemaParser(Parser):
             self.parse_root_type(name, obj, path)
         elif obj.type == 'object':
             self.parse_object(name, obj, path)
-        elif obj.enum:
+        elif obj.enum and not self.should_parse_enum_as_literal(obj):
             self.parse_enum(name, obj, path)
         else:
             self.parse_root_type(name, obj, path)
@@ -1553,8 +1561,8 @@ class JsonSchemaParser(Parser):
                         reference = self.model_resolver.get(reserved_path)
                         if not reference or reference.loaded:
                             continue
+                        object_paths = reserved_path.split('#/', 1)[-1].split('/')
                         path = reserved_path.split('/')
-                        _, *object_paths = path
                         models = get_model_by_path(raw, object_paths)
                         model_name = object_paths[-1]
                         self.parse_obj(
